import Link from 'next/link';
import { Clock, Dumbbell } from 'lucide-react';
import { Workout } from '@/types';

export function WorkoutCard({ workout }: { workout: Workout }) {
  const difficultyColors = {
    recovery: 'var(--sage-300)',
    easy: 'var(--sage-400)',
    moderate: 'var(--pink-300)',
    strenuous: 'var(--pink-400)'
  };

  return (
    <article className="project">
      <h3>{workout.title}</h3>
      {workout.description && <p>{workout.description}</p>}
      
      <div style={{ display: 'flex', gap: 'var(--space-md)', margin: 'var(--space-sm) 0' }}>
        <span style={{ 
          display: 'inline-flex', 
          alignItems: 'center', 
          gap: 'var(--space-xs)',
          color: difficultyColors[workout.difficulty]
        }}>
          <Dumbbell size={16} />
          {workout.difficulty}
        </span>
        <span style={{ display: 'inline-flex', alignItems: 'center', gap: 'var(--space-xs)' }}>
          <Clock size={16} />
          {workout.duration} mins
        </span>
      </div>

      <Link href={`/workouts/${workout.id}`} style={{ display: 'inline-flex', alignItems: 'center' }}>
        View Workout →
      </Link>
    </article>
  );
}